/**
 * Calculates the Equated Monthly Installment (EMI) for a loan.
 * @param principal - The loan amount (principal).
 * @param annualInterestRate - The annual interest rate (in percentage).
 * @param loanTenureInYears - The loan tenure in years.
 * @returns The EMI value.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateEMI(principal: number, annualInterestRate: number, loanTenureInYears: number): number;
/**
 * Calculates the GST (Goods and Services Tax) amount and the total price including GST.
 * @param originalPrice - The original price of the product or service.
 * @param gstRate - The GST rate (in percentage).
 * @returns An object containing the GST amount and the total price including GST.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateGST(originalPrice: number, gstRate: number): {
    gstAmount: number;
    totalPrice: number;
};
